Americanas
============

Americanas crawler and scraper using beautifulsoup4.

Usage example
-------------
    Para utilizar em sua aplicação basta instanciar
    passando os parâmetros da pesquisa.
    # Exemplo: americanas_scraper.search(url="")

Cli usage
-------------
    americanas --url=URL

Installing
----------
    pip install pip install americanas_scraper